# Step 3: Discover and Prioritize Technology Obsolescence Risks
### On this page
  * [Identify Applications With Unaddressed Risks](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks#identify-applications-with-unaddressed-risks)
  * [Prioritize Risks by Business Criticality](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks#prioritize-risks-by-business-criticality)
  * [Monitor Risks Over Time](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks#monitor-risks-over-time)
  * [Next Step](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks#next-step)


Analyze and prioritize technological risks using insights obtained from reports.
When you have built sufficient data for a meaningful analysis, use reports and diagrams to analyze and prioritize technological risks. SAP LeanIX Technology Risk and Compliance offers additional views in the reports for better insights into underlying risks. Here are a ways to use reports to assess risk:
